Learn R Programming

drcarlate (version 1.2.0)

JLTZ: Reproduce the results of the Jiang et al. (2022)

Description

Helps the user reproduce the results of the data simulation section of Jiang et al. (2022).

Usage

JLTZ(iMonte, dgptype, n, g, pi, iPert, iq = 0.05, iridge = 0.001, seed = 1)

Value

A table summarizing the estimated results, mProd.

Arguments

iMonte

A scalar. Monte Carlo sizes.

dgptype

A scalar. The value can be string 1, 2, or 3, respectively corresponding to the three random data generation methods in the paper (See Jiang et al. (2022) for DGP details).

n

Sample size.

g

Number of strata. We set g=4 in Jiang et al. (2022).

pi

Targeted assignment probability across strata.

iPert

A scalar. iPert = 0 means size. Otherwise means power: iPert is the perturbation of false null.

iq

A scalar. Size of hypothesis testing. The authors set iq = 0.05.

iridge

A scalar. The penalization parameter in ridge regression.

seed

A scalar. The random seed, the authors set seed = 1 in Jiang et al. (2022).

References

Jiang L, Linton O B, Tang H, Zhang Y. Improving estimation efficiency via regression-adjustment in covariate-adaptive randomizations with imperfect compliance [J]. 2022.

Examples

Run this code
# \donttest{
# size, iPert = 0
JLTZ(iMonte = 10, dgptype = 1, n = 200, g = 4,
    pi = c(0.5, 0.5, 0.5, 0.5), iPert = 0, iq = 0.05, iridge = 0.001, seed = 1)

# power, iPert = 1
JLTZ(iMonte = 10, dgptype = 1, n = 200, g = 4,
    pi = c(0.5, 0.5, 0.5, 0.5), iPert = 1, iq = 0.05, iridge = 0.001, seed = 1)
# }

Run the code above in your browser using DataLab