Pihat computes the targeted treatment assignment probabilities across all strata in Jiang et al. (2022) and stacks them in an nx1 vector.
Usage
pihat(A, S, stratnum = NULL)
Value
A nx1 cector, each element corresponds to the targeted treatment assignment probabilities across all strata in Jiang et al. (2022).
Arguments
A
A nx1 vector.
S
A nx1 vector.
stratnum
A nx1 vector about the unique strara numbers, the default value is NULL.
References
Jiang L, Linton O B, Tang H, Zhang Y. Improving estimation efficiency via regression-adjustment in covariate-adaptive randomizations with imperfect compliance [J]. 2022.