splinebasis: For each column of an input matrix, elements which are less than the median of that column are set to 0, leaving the rest of the elements unchanged
Description
For each column of an input matrix, elements which are less than the median of that column are set to 0, leaving the rest of the elements unchanged.
Usage
splinebasis(X)
Value
H A n x K matrix. All elements of the X that are less than
the median of their corresponding columns are set to 0, leaving the rest unchanged.
Arguments
X
The extra covariates, a n x K matrix. No constant included.